@@ -8,7 +8,7 @@ import pprint
 import re
 import sys
 import time
-from typing import Callable, Sequence
+from collections.abc import Callable, Sequence
 
 from anki import media_pb2
 from anki._legacy import DeprecatedNamesMixin, deprecated_keywords
