@@ -5,6 +5,8 @@ from __future__ import annotations
 
 import logging
 import sys
+from collections.abc import Callable
+from typing import TYPE_CHECKING, Any, Union, cast
 
 if sys.version_info[0] < 3 or sys.version_info[1] < 9:
     raise Exception("Anki requires Python 3.9+")
@@ -43,7 +45,6 @@ import os
 import tempfile
 import traceback
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Optional, cast
 
 import anki.lang
 from anki._backend import RustBackend
@@ -54,6 +55,7 @@ from anki.utils import checksum, is_lin, is_mac
 from aqt import gui_hooks
 from aqt.log import setup_logging
 from aqt.qt import *
+from aqt.qt import sip
 from aqt.utils import TR, tr
 
 if TYPE_CHECKING:
@@ -85,8 +87,8 @@ appHelpSite = HELP_SITE
 from aqt.main import AnkiQt  # isort:skip
 from aqt.profiles import ProfileManager, VideoDriver  # isort:skip
 
-profiler: Optional[cProfile.Profile] = None
-mw: Optional[AnkiQt] = None  # set on init
+profiler: cProfile.Profile | None = None
+mw: AnkiQt = None  # type: ignore # set on init
 
 import aqt.forms
 
@@ -147,7 +149,7 @@ class DialogManager:
     def allClosed(self) -> bool:
         return not any(x[1] for x in self._dialogs.values())
 
-    def closeAll(self, onsuccess: Callable[[], None]) -> Optional[bool]:
+    def closeAll(self, onsuccess: Callable[[], None]) -> bool | None:
         # can we close immediately?
         if self.allClosed():
             onsuccess()
@@ -174,7 +176,7 @@ class DialogManager:
         return True
 
     def register_dialog(
-        self, name: str, creator: Union[Callable, type], instance: Optional[Any] = None
+        self, name: str, creator: Callable | type, instance: Any | None = None
     ) -> None:
         """Allows add-ons to register a custom dialog to be managed by Anki's dialog
         manager, which ensures that only one copy of the window is open at once,
@@ -212,19 +214,19 @@ dialogs = DialogManager()
 
 # A reference to the Qt translator needs to be held to prevent it from
 # being immediately deallocated.
-_qtrans: Optional[QTranslator] = None
+_qtrans: QTranslator | None = None
 
 
 def setupLangAndBackend(
     pm: ProfileManager,
     app: QApplication,
-    force: Optional[str] = None,
+    force: str | None = None,
     firstTime: bool = False,
 ) -> RustBackend:
     global _qtrans
     try:
         locale.setlocale(locale.LC_ALL, "")
-    except:
+    except Exception:
         pass
 
     # add _ and ngettext globals used by legacy code
@@ -271,7 +273,10 @@ def setupLangAndBackend(
     if _qtrans.load(f"qtbase_{qt_lang}", qt_dir):
         app.installTranslator(_qtrans)
 
-    return anki.lang.current_i18n
+    backend = anki.lang.current_i18n
+    assert backend is not None
+
+    return backend
 
 
 # App initialisation
@@ -281,12 +286,14 @@ def setupLangAndBackend(
 class NativeEventFilter(QAbstractNativeEventFilter):
     def nativeEventFilter(
         self, eventType: Any, message: Any
-    ) -> tuple[bool, Optional[sip.voidptr]]:
+    ) -> tuple[bool, sip.voidptr | None]:
+
         if eventType == "windows_generic_MSG":
-            import ctypes
+            import ctypes.wintypes
 
             msg = ctypes.wintypes.MSG.from_address(int(message))
             if msg.message == 17:  # WM_QUERYENDSESSION
+                assert mw is not None
                 if mw.can_auto_sync():
                     mw.app._set_windows_shutdown_block_reason(tr.sync_syncing())
                     mw.progress.single_shot(100, mw.unloadProfileAndExit)
@@ -316,6 +323,7 @@ class AnkiApp(QApplication):
             import ctypes
             from ctypes import windll, wintypes  # type: ignore
 
+            assert mw is not None
             windll.user32.ShutdownBlockReasonCreate(
                 wintypes.HWND.from_param(int(mw.effectiveWinId())),
                 ctypes.c_wchar_p(reason),
@@ -325,6 +333,7 @@ class AnkiApp(QApplication):
         if is_win:
             from ctypes import windll, wintypes  # type: ignore
 
+            assert mw is not None
             windll.user32.ShutdownBlockReasonDestroy(
                 wintypes.HWND.from_param(int(mw.effectiveWinId())),
             )
@@ -379,7 +388,9 @@ class AnkiApp(QApplication):
     # OS X file/url handler
     ##################################################
 
-    def event(self, evt: QEvent) -> bool:
+    def event(self, evt: QEvent | None) -> bool:
+        assert evt is not None
+
         if evt.type() == QEvent.Type.FileOpen:
             self.appMsg.emit(evt.file() or "raise")  # type: ignore
             return True
@@ -388,7 +399,9 @@ class AnkiApp(QApplication):
     # Global cursor: pointer for Qt buttons
     ##################################################
 
-    def eventFilter(self, src: Any, evt: QEvent) -> bool:
+    def eventFilter(self, src: Any, evt: QEvent | None) -> bool:
+        assert evt is not None
+
         pointer_classes = (
             QPushButton,
             QCheckBox,
@@ -538,6 +551,8 @@ PROFILE_CODE = os.environ.get("ANKI_PROFILE_CODE")
 
 
 def write_profile_results() -> None:
+    assert profiler is not None
+
     profiler.disable()
     profile = "out/anki.prof"
     profiler.dump_stats(profile)
@@ -556,7 +571,7 @@ def run() -> None:
         )
 
 
-def _run(argv: Optional[list[str]] = None, exec: bool = True) -> Optional[AnkiApp]:
+def _run(argv: list[str] | None = None, exec: bool = True) -> AnkiApp | None:
     """Start AnkiQt application or reuse an existing instance if one exists.
 
     If the function is invoked with exec=False, the AnkiQt will not enter
@@ -622,7 +637,7 @@ def _run(argv: Optional[list[str]] = None, exec: bool = True) -> Optional[AnkiAp
         pmLoadResult = pm.setupMeta()
 
         Collection.initialize_backend_logging()
-    except:
+    except Exception:
         # will handle below
         traceback.print_exc()
         pm = None
@@ -658,17 +673,12 @@ def _run(argv: Optional[list[str]] = None, exec: bool = True) -> Optional[AnkiAp
 
     # create the app
     QCoreApplication.setApplicationName("Anki")
-    QGuiApplication.setDesktopFileName("anki.desktop")
+    QGuiApplication.setDesktopFileName("anki")
     app = AnkiApp(argv)
     if app.secondInstance():
         # we've signaled the primary instance, so we should close
         return None
 
-    setup_logging(
-        pm.addon_logs(),
-        level=logging.DEBUG if int(os.getenv("ANKIDEV", "0")) else logging.INFO,
-    )
-
     if not pm:
         if i18n_setup:
             QMessageBox.critical(
@@ -680,6 +690,11 @@ def _run(argv: Optional[list[str]] = None, exec: bool = True) -> Optional[AnkiAp
             QMessageBox.critical(None, "Startup Failed", "Unable to create data folder")
         return None
 
+    setup_logging(
+        pm.addon_logs(),
+        level=logging.DEBUG if int(os.getenv("ANKIDEV", "0")) else logging.INFO,
+    )
+
     # disable icons on mac; this must be done before window created
     if is_mac:
         app.setAttribute(Qt.ApplicationAttribute.AA_DontShowIconsInMenus)
@@ -712,7 +727,7 @@ def _run(argv: Optional[list[str]] = None, exec: bool = True) -> Optional[AnkiAp
     # we must have a usable temp dir
     try:
         tempfile.gettempdir()
-    except:
+    except Exception:
         QMessageBox.critical(
             None,
             tr.qt_misc_error(),
