@@ -2,6 +2,7 @@
 # License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
 
 import platform
+from collections.abc import Callable
 
 import aqt.forms
 from anki.lang import without_unicode_isolation
@@ -36,14 +37,21 @@ def show(mw: aqt.AnkiQt) -> QDialog:
         txt = supportText()
         if mw.addonManager.dirty:
             txt += "\n" + addon_debug_info()
-        QApplication.clipboard().setText(txt)
+        clipboard = QApplication.clipboard()
+        assert clipboard is not None
+        clipboard.setText(txt)
         tooltip(tr.about_copied_to_clipboard(), parent=dialog)
 
     btn = QPushButton(tr.about_copy_debug_info())
     qconnect(btn.clicked, on_copy)
     abt.buttonBox.addButton(btn, QDialogButtonBox.ButtonRole.ActionRole)
-    abt.buttonBox.button(QDialogButtonBox.StandardButton.Ok).setFocus()
+
+    ok_button = abt.buttonBox.button(QDialogButtonBox.StandardButton.Ok)
+    assert ok_button is not None
+    ok_button.setFocus()
+
     btnLayout = abt.buttonBox.layout()
+    assert btnLayout is not None
     btnLayout.setContentsMargins(12, 12, 12, 12)
 
     # WebView cleanup
@@ -51,7 +59,7 @@ def show(mw: aqt.AnkiQt) -> QDialog:
 
     def on_dialog_destroyed() -> None:
         abt.label.cleanup()
-        abt.label = None
+        abt.label = None  # type: ignore
 
     qconnect(dialog.destroyed, on_dialog_destroyed)
 
@@ -79,6 +87,7 @@ def show(mw: aqt.AnkiQt) -> QDialog:
             "Andreas Klauer",
             "Andrew Wright",
             "Aristotelis P.",
+            "Ben Nguyen",
             "Bernhard Ibertsberger",
             "C. van Rooyen",
             "Cenaris Mori",
@@ -86,6 +95,7 @@ def show(mw: aqt.AnkiQt) -> QDialog:
             "Christian Krause",
             "Christian Rusche",
             "Dave Druelinger",
+            "David Culley",
             "David Smith",
             "Dmitry Mikheev",
             "Dotan Cohen",
@@ -144,6 +154,7 @@ def show(mw: aqt.AnkiQt) -> QDialog:
             "Susanna Björverud",
             "Sylvain Durand",
             "Tacutu",
+            "Taylor Obyen",
             "Timm Preetz",
             "Timo Paulssen",
             "Ursus",
@@ -194,6 +205,9 @@ def show(mw: aqt.AnkiQt) -> QDialog:
             "Marko Sisovic",
             "Lucas Scharenbroch",
             "Antoine Q.",
+            "Ian Samir Yep Manzano",
+            "Asuka Minato",
+            "Eros Cardoso",
         )
     )
 
