@@ -9,13 +9,16 @@ import json
 import logging
 import os
 import re
+import sys
+import traceback
 import zipfile
 from collections import defaultdict
+from collections.abc import Callable, Iterable, Sequence
 from concurrent.futures import Future
 from dataclasses import dataclass
 from datetime import datetime
 from pathlib import Path
-from typing import IO, Any, Callable, Iterable, Sequence, Union
+from typing import IO, Any, Union
 from urllib.parse import parse_qs, urlparse
 from zipfile import ZipFile
 
@@ -247,7 +250,7 @@ class AddonManager:
                 __import__(addon.dir_name)
             except AbortAddonImport:
                 pass
-            except:
+            except Exception:
                 name = html.escape(addon.human_name())
                 page = addon.page()
                 if page:
@@ -340,7 +343,7 @@ class AddonManager:
         except json.JSONDecodeError as e:
             print(f"json error in add-on {module}:\n{e}")
             return dict()
-        except:
+        except Exception:
             # missing meta file, etc
             return dict()
 
@@ -406,7 +409,9 @@ class AddonManager:
                 all_conflicts[other_dir].append(addon.dir_name)
         return all_conflicts
 
-    def _disableConflicting(self, module: str, conflicts: list[str] = None) -> set[str]:
+    def _disableConflicting(
+        self, module: str, conflicts: list[str] | None = None
+    ) -> set[str]:
         if not self.isEnabled(module):
             # disabled add-ons should not trigger conflict handling
             return set()
@@ -643,7 +648,7 @@ class AddonManager:
         try:
             with open(path, encoding="utf8") as f:
                 return json.load(f)
-        except:
+        except Exception:
             return None
 
     def set_config_help_action(self, module: str, action: Callable[[], str]) -> None:
@@ -1061,7 +1066,12 @@ class GetAddons(QDialog):
     def accept(self) -> None:
         # get codes
         try:
-            ids = [int(n) for n in self.form.code.text().split()]
+            sids = self.form.code.text().split()
+            sids = [
+                re.sub(r"^https://ankiweb.net/shared/info/(\d+)$", r"\1", id_)
+                for id_ in sids
+            ]
+            ids = [int(id_) for id_ in sids]
         except ValueError:
             showWarning(tr.addons_invalid_code())
             return
@@ -1083,9 +1093,11 @@ def download_addon(client: HttpClient, id: int) -> DownloadOk | DownloadError:
 
         data = client.stream_content(resp)
 
-        fname = re.match(
+        match = re.match(
             "attachment; filename=(.+)", resp.headers["content-disposition"]
-        ).group(1)
+        )
+        assert match is not None
+        fname = match.group(1)
 
         meta = extract_meta_from_download_url(resp.url)
 
@@ -1113,11 +1125,14 @@ def extract_meta_from_download_url(url: str) -> ExtractedDownloadMeta:
     urlobj = urlparse(url)
     query = parse_qs(urlobj.query)
 
+    def get_first_element(elements: list[str]) -> int:
+        return int(elements[0])
+
     meta = ExtractedDownloadMeta(
-        mod_time=int(query.get("t")[0]),
-        min_point_version=int(query.get("minpt")[0]),
-        max_point_version=int(query.get("maxpt")[0]),
-        branch_index=int(query.get("bidx")[0]),
+        mod_time=get_first_element(query["t"]),
+        min_point_version=get_first_element(query["minpt"]),
+        max_point_version=get_first_element(query["maxpt"]),
+        branch_index=get_first_element(query["bidx"]),
     )
 
     return meta
@@ -1245,7 +1260,9 @@ class DownloaderInstaller(QObject):
         self.mgr.mw.progress.single_shot(50, lambda: self.on_done(self.log))
 
 
-def show_log_to_user(parent: QWidget, log: list[DownloadLogEntry]) -> None:
+def show_log_to_user(
+    parent: QWidget, log: list[DownloadLogEntry], title: str = "Anki"
+) -> None:
     have_problem = download_encountered_problem(log)
 
     if have_problem:
@@ -1255,9 +1272,9 @@ def show_log_to_user(parent: QWidget, log: list[DownloadLogEntry]) -> None:
     text += f"<br><br>{download_log_to_html(log)}"
 
     if have_problem:
-        showWarning(text, textFormat="rich", parent=parent)
+        showWarning(text, textFormat="rich", parent=parent, title=title)
     else:
-        showInfo(text, parent=parent)
+        showInfo(text, parent=parent, title=title)
 
 
 def download_addons(
@@ -1542,6 +1559,32 @@ def prompt_to_update(
     ChooseAddonsToUpdateDialog(parent, mgr, updated_addons).ask(after_choosing)
 
 
+def install_or_update_addon(
+    parent: QWidget,
+    mgr: AddonManager,
+    addon_id: int,
+    on_done: Callable[[list[DownloadLogEntry]], None],
+) -> None:
+    def check() -> list[AddonInfo]:
+        return fetch_update_info([addon_id])
+
+    def update_info_received(future: Future) -> None:
+        try:
+            items = future.result()
+            updated_addons = mgr.get_updated_addons(items)
+            if not updated_addons:
+                on_done([])
+                return
+            client = HttpClient()
+            download_addons(
+                parent, mgr, [addon.id for addon in updated_addons], on_done, client
+            )
+        except Exception as exc:
+            on_done([(addon_id, DownloadError(exception=exc))])
+
+    mgr.mw.taskman.run_in_background(check, update_info_received)
+
+
 # Editing config
 ######################################################################
 
