@@ -8,10 +8,13 @@ import gc
 import os
 import re
 import signal
+import sys
+import traceback
 import weakref
 from argparse import Namespace
+from collections.abc import Callable, Sequence
 from concurrent.futures import Future
-from typing import Any, Literal, Sequence, TypeVar, cast
+from typing import Any, Literal, TypeVar, cast
 
 import anki
 import anki.cards
@@ -109,7 +112,6 @@ class MainWebView(AnkiWebView):
         self.setFocusPolicy(Qt.FocusPolicy.WheelFocus)
         self.setMinimumWidth(400)
         self.setAcceptDrops(True)
-        print("todo: windows paths in import screen")
 
     # Importing files via drag & drop
     ##########################################################################
@@ -199,7 +201,7 @@ class AnkiQt(QMainWindow):
             self.setupUI()
             self.setupAddons(args)
             self.finish_ui_setup()
-        except:
+        except Exception:
             showInfo(tr.qt_misc_error_during_startup(val=traceback.format_exc()))
             sys.exit(1)
         # must call this after ui set up
@@ -350,7 +352,7 @@ class AnkiQt(QMainWindow):
         f.profiles.addItems(profs)
         try:
             idx = profs.index(self.pm.name)
-        except:
+        except Exception:
             idx = 0
         f.profiles.setCurrentRow(idx)
 
@@ -421,32 +423,59 @@ class AnkiQt(QMainWindow):
         self.pm.remove(self.pm.name)
         self.refreshProfilesList()
 
-    def onOpenBackup(self) -> None:
-        if not askUser(
-            tr.qt_misc_replace_your_collection_with_an_earlier(),
-            msgfunc=QMessageBox.warning,
-            defaultno=True,
-        ):
-            return
+    def _handle_load_backup_success(self) -> None:
+        """
+        Actions that occur when profile backup has been loaded successfully
+        """
+        if self.state == "profileManager":
+            self.profileDiag.closeWithoutQuitting()
 
-        def doOpen(path: str) -> None:
-            self._openBackup(path)
+        self.loadProfile()
+
+    def _handle_load_backup_failure(self, error: Exception) -> None:
+        """
+        Actions that occur when a profile has loaded unsuccessfully
+        """
+        showWarning(str(error))
+        if self.state != "profileManager":
+            self.loadProfile()
+
+    def onOpenBackup(self) -> None:
+
+        def do_open(path: str) -> None:
+            if not askUser(
+                tr.qt_misc_replace_your_collection_with_an_earlier2(
+                    os.path.basename(path)
+                ),
+                msgfunc=QMessageBox.warning,
+                defaultno=True,
+            ):
+                return
+
+            showInfo(tr.qt_misc_automatic_syncing_and_backups_have_been())
+
+            # Collection is still loaded if called from main window, so we unload. This is already
+            # unloaded if called from the ProfileManager window.
+            if self.col:
+                self.unloadProfile(lambda: self._start_restore_backup(path))
+                return
+
+            self._start_restore_backup(path)
 
         getFile(
-            self.profileDiag,
+            self.profileDiag if self.state == "profileManager" else self,
             tr.qt_misc_revert_to_backup(),
-            cb=doOpen,  # type: ignore
+            cb=do_open,  # type: ignore
             filter="*.colpkg",
             dir=self.pm.backupFolder(),
         )
 
-    def _openBackup(self, path: str) -> None:
+    def _start_restore_backup(self, path: str):
         self.restoring_backup = True
-        showInfo(tr.qt_misc_automatic_syncing_and_backups_have_been())
 
         import_collection_package_op(
-            self, path, success=self.onOpenProfile
-        ).run_in_background()
+            self, path, success=self._handle_load_backup_success
+        ).failure(self._handle_load_backup_failure).run_in_background()
 
     def _on_downgrade(self) -> None:
         self.progress.start()
@@ -526,8 +555,8 @@ class AnkiQt(QMainWindow):
             )
 
         refresh_reviewer_on_day_rollover_change()
-        self.maybe_auto_sync_on_open_close(_onsuccess)
         gui_hooks.profile_did_open()
+        self.maybe_auto_sync_on_open_close(_onsuccess)
 
     def unloadProfile(self, onsuccess: Callable) -> None:
         def callback() -> None:
@@ -680,7 +709,7 @@ class AnkiQt(QMainWindow):
             self.maybeOptimize()
             if not dev_mode:
                 corrupt = self.col.db.scalar("pragma quick_check") != "ok"
-        except:
+        except Exception:
             corrupt = True
 
         try:
@@ -692,7 +721,7 @@ class AnkiQt(QMainWindow):
                         force=False,
                         wait_for_completion=False,
                     )
-                except:
+                except Exception:
                     print("backup on close failed")
             self.col.close(downgrade=False)
         except Exception as e:
@@ -859,8 +888,8 @@ class AnkiQt(QMainWindow):
     def requireReset(
         self,
         modal: bool = False,
-        reason: Any = None,
-        context: Any = None,
+        reason: Any | None = None,
+        context: Any | None = None,
     ) -> None:
         traceback.print_stack(file=sys.stdout)
         print("requireReset() is obsolete; please use CollectionOp()")
@@ -1346,6 +1375,7 @@ title="{}" {}>{}</button>""".format(
         qconnect(m.actionImport.triggered, self.onImport)
         qconnect(m.actionExport.triggered, self.onExport)
         qconnect(m.action_create_backup.triggered, self.on_create_backup_now)
+        qconnect(m.action_open_backup.triggered, self.onOpenBackup)
         qconnect(m.actionExit.triggered, self.close)
 
         # Help
@@ -1428,7 +1458,8 @@ title="{}" {}>{}</button>""".format(
     def setup_auto_update(self, _log: list[DownloadLogEntry]) -> None:
         from aqt.update import check_for_update
 
-        check_for_update()
+        if aqt.mw.pm.check_for_updates():
+            check_for_update()
 
     # Timers
     ##########################################################################
