@@ -11,10 +11,10 @@ import re
 import sys
 import threading
 import traceback
+from collections.abc import Callable
 from dataclasses import dataclass
 from errno import EPROTOTYPE
 from http import HTTPStatus
-from typing import Callable
 
 import flask
 import flask_cors
@@ -457,8 +457,8 @@ def update_deck_configs() -> bytes:
             update.max = val.total_cards
             update.value = val.current_cards
             update.label = val.label
-        elif progress.HasField("compute_weights"):
-            val2 = progress.compute_weights
+        elif progress.HasField("compute_params"):
+            val2 = progress.compute_params
             # prevent an indeterminate progress bar from appearing at the start of each preset
             update.max = max(val2.total, 1)
             update.value = val2.current
@@ -608,6 +608,7 @@ exposed_backend_list = [
     "get_change_notetype_info",
     # StatsService
     "card_stats",
+    "get_review_logs",
     "graphs",
     "get_graph_preferences",
     "set_graph_preferences",
@@ -620,11 +621,12 @@ exposed_backend_list = [
     "update_image_occlusion_note",
     "get_image_occlusion_fields",
     # SchedulerService
-    "compute_fsrs_weights",
+    "compute_fsrs_params",
     "compute_optimal_retention",
     "set_wants_abort",
-    "evaluate_weights",
+    "evaluate_params",
     "get_optimal_retention_parameters",
+    "simulate_fsrs_review",
 ]
 
 
@@ -733,8 +735,12 @@ def _extract_page_context() -> PageContext:
         return PageContext.NON_LEGACY_PAGE
     elif referer.path == "/_anki/legacyPageData":
         query_params = parse_qs(referer.query)
-        id = int(query_params.get("id", [None])[0])
-        return aqt.mw.mediaServer.get_page_context(id)
+        query_id = query_params.get("id")
+        if not query_id:
+            return PageContext.UNKNOWN
+        id = int(query_id[0])
+        page_context = aqt.mw.mediaServer.get_page_context(id)
+        return page_context if page_context else PageContext.UNKNOWN
     else:
         return PageContext.UNKNOWN
 
