@@ -5,13 +5,16 @@ from __future__ import annotations
 
 import functools
 import re
+from collections.abc import Callable
 
 import anki.lang
 import aqt
 import aqt.forms
 import aqt.operations
 from anki.collection import OpChanges
+from anki.utils import is_mac
 from aqt import AnkiQt
+from aqt.ankihub import ankihub_login, ankihub_logout
 from aqt.operations.collection import set_preferences
 from aqt.profiles import VideoDriver
 from aqt.qt import *
@@ -36,13 +39,23 @@ class Preferences(QDialog):
         self.prof = self.mw.pm.profile
         self.form = aqt.forms.preferences.Ui_Preferences()
         self.form.setupUi(self)
+        for spinbox in (
+            self.form.lrnCutoff,
+            self.form.dayOffset,
+            self.form.timeLimit,
+            self.form.network_timeout,
+        ):
+            spinbox.setSuffix(f" {spinbox.suffix()}")
+
         disable_help_button(self)
-        self.form.buttonBox.button(QDialogButtonBox.StandardButton.Help).setAutoDefault(
-            False
-        )
-        self.form.buttonBox.button(
-            QDialogButtonBox.StandardButton.Close
-        ).setAutoDefault(False)
+        help_button = self.form.buttonBox.button(QDialogButtonBox.StandardButton.Help)
+        assert help_button is not None
+        help_button.setAutoDefault(False)
+
+        close_button = self.form.buttonBox.button(QDialogButtonBox.StandardButton.Close)
+        assert close_button is not None
+        close_button.setAutoDefault(False)
+
         qconnect(
             self.form.buttonBox.helpRequested, lambda: openHelp(HelpPage.PREFERENCES)
         )
@@ -198,13 +211,19 @@ class Preferences(QDialog):
         self.form.custom_sync_url.setText(self.mw.pm.custom_sync_url())
         self.form.network_timeout.setValue(self.mw.pm.network_timeout())
 
+        self.form.check_for_updates.setChecked(self.mw.pm.check_for_updates())
+        qconnect(self.form.check_for_updates.stateChanged, self.mw.pm.set_update_check)
+
         self.update_login_status()
         qconnect(self.form.syncLogout.clicked, self.sync_logout)
         qconnect(self.form.syncLogin.clicked, self.sync_login)
+        qconnect(self.form.syncAnkiHubLogout.clicked, self.ankihub_sync_logout)
+        qconnect(self.form.syncAnkiHubLogin.clicked, self.ankihub_sync_login)
 
     def update_login_status(self) -> None:
+        assert self.prof is not None
         if not self.prof.get("syncKey"):
-            self.form.syncUser.setText(tr.preferences_not_logged_in())
+            self.form.syncUser.setText(tr.preferences_ankiweb_intro())
             self.form.syncLogin.setVisible(True)
             self.form.syncLogout.setVisible(False)
         else:
@@ -212,11 +231,21 @@ class Preferences(QDialog):
             self.form.syncLogin.setVisible(False)
             self.form.syncLogout.setVisible(True)
 
+        if not self.mw.pm.ankihub_token():
+            self.form.syncAnkiHubUser.setText(tr.preferences_ankihub_intro())
+            self.form.syncAnkiHubLogin.setVisible(True)
+            self.form.syncAnkiHubLogout.setVisible(False)
+        else:
+            self.form.syncAnkiHubUser.setText(self.mw.pm.ankihub_username())
+            self.form.syncAnkiHubLogin.setVisible(False)
+            self.form.syncAnkiHubLogout.setVisible(True)
+
     def on_media_log(self) -> None:
         self.mw.media_syncer.show_sync_log()
 
     def sync_login(self) -> None:
         def on_success():
+            assert self.prof is not None
             if self.prof.get("syncKey"):
                 self.update_login_status()
                 self.confirm_sync_after_login()
@@ -227,10 +256,24 @@ class Preferences(QDialog):
         if self.mw.media_syncer.is_syncing():
             showWarning("Can't log out while sync in progress.")
             return
+        assert self.prof is not None
         self.prof["syncKey"] = None
         self.mw.col.media.force_resync()
         self.update_login_status()
 
+    def ankihub_sync_login(self) -> None:
+        def on_success():
+            if self.mw.pm.ankihub_token():
+                self.update_login_status()
+
+        ankihub_login(self.mw, on_success)
+
+    def ankihub_sync_logout(self) -> None:
+        ankihub_token = self.mw.pm.ankihub_token()
+        if ankihub_token is None:
+            return
+        ankihub_logout(self.mw, self.update_login_status, ankihub_token)
+
     def confirm_sync_after_login(self) -> None:
         from aqt import mw
 
@@ -238,6 +281,7 @@ class Preferences(QDialog):
             self.accept_with_callback(self.mw.on_sync_button_clicked)
 
     def update_network(self) -> None:
+        assert self.prof is not None
         self.prof["autoSync"] = self.form.syncOnProgramOpen.isChecked()
         self.prof["syncMedia"] = self.form.syncMedia.isChecked()
         self.mw.pm.set_periodic_sync_media_minutes(
@@ -315,7 +359,6 @@ class Preferences(QDialog):
         )
         self.form.styleLabel.setVisible(not is_win)
         self.form.styleComboBox.setVisible(not is_win)
-        self.form.legacy_import_export.setChecked(self.mw.pm.legacy_import_export())
         qconnect(self.form.resetWindowSizes.clicked, self.on_reset_window_sizes)
 
         self.setup_language()
@@ -333,8 +376,6 @@ class Preferences(QDialog):
             self.mw.pm.setUiScale(newScale)
             restart_required = True
 
-        self.mw.pm.set_legacy_import_export(self.form.legacy_import_export.isChecked())
-
         if restart_required:
             showInfo(tr.preferences_changes_will_take_effect_when_you())
 
@@ -344,6 +385,7 @@ class Preferences(QDialog):
         self.mw.set_theme(Theme(index))
 
     def on_reset_window_sizes(self) -> None:
+        assert self.prof is not None
         regexp = re.compile(r"(Geom(etry)?|State|Splitter|Header)(\d+.\d+)?$")
         for key in list(self.prof.keys()):
             if regexp.search(key):
@@ -376,7 +418,7 @@ class Preferences(QDialog):
             lang = lang.replace("-", "_")
         try:
             return codes.index(lang)
-        except:
+        except Exception:
             return codes.index("en_US")
 
     def on_language_index_changed(self, idx: int) -> None:
