@@ -9,12 +9,14 @@ import re
 import subprocess
 import sys
 import time
+import traceback
 import wave
 from abc import ABC, abstractmethod
+from collections.abc import Callable
 from concurrent.futures import Future
 from operator import itemgetter
 from pathlib import Path
-from typing import Any, Callable, cast
+from typing import Any, cast
 
 from markdown import markdown
 
