@@ -189,6 +189,7 @@ class MacTTSPlayer(TTSProcessPlayer):
             stderr=subprocess.DEVNULL,
         )
         # write the input text to stdin
+        assert self._process.stdin is not None
         self._process.stdin.write(tag.field_text.encode("utf8"))
         self._process.stdin.close()
         self._wait_for_termination(tag)
@@ -247,6 +248,7 @@ class MacTTSFilePlayer(MacTTSPlayer):
             stderr=subprocess.DEVNULL,
         )
         # write the input text to stdin
+        assert self._process.stdin is not None
         self._process.stdin.write(tag.field_text.encode("utf8"))
         self._process.stdin.close()
         self._wait_for_termination(tag)
@@ -504,13 +506,13 @@ if is_win:
         def _voice_to_objects(self, voice: Any) -> list[WindowsVoice]:
             try:
                 langs = voice.GetAttribute("language")
-            except:
+            except Exception:
                 # no associated language; ignore
                 return []
             langs = lcid_hex_str_to_lang_codes(langs)
             try:
                 name = voice.GetAttribute("name")
-            except:
+            except Exception:
                 # some voices may not have a name
                 name = "unknown"
             name = self._tidy_name(name)
