@@ -5,10 +5,12 @@ from __future__ import annotations
 
 import dataclasses
 import json
+import os
 import re
 import sys
+from collections.abc import Callable, Sequence
 from enum import Enum
-from typing import TYPE_CHECKING, Any, Callable, Optional, Sequence, cast
+from typing import TYPE_CHECKING, Any, cast
 
 import anki
 import anki.lang
@@ -17,6 +19,7 @@ from anki.lang import is_rtl
 from anki.utils import hmr_mode, is_lin, is_mac, is_win
 from aqt import colors, gui_hooks
 from aqt.qt import *
+from aqt.qt import sip
 from aqt.theme import theme_manager
 from aqt.utils import askUser, is_gesture_or_zoom_event, openLink, showInfo, tr
 
@@ -86,17 +89,23 @@ class AnkiWebPage(QWebEnginePage):
         script.setWorldId(QWebEngineScript.ScriptWorldId.MainWorld)
         script.setInjectionPoint(QWebEngineScript.InjectionPoint.DocumentReady)
         script.setRunsOnSubFrames(False)
-        self.profile().scripts().insert(script)
+
+        profile = self.profile()
+        assert profile is not None
+        scripts = profile.scripts()
+        assert scripts is not None
+        scripts.insert(script)
 
     def javaScriptConsoleMessage(
         self,
         level: QWebEnginePage.JavaScriptConsoleMessageLevel,
-        msg: str,
+        msg: str | None,
         line: int,
-        srcID: str,
+        srcID: str | None,
     ) -> None:
         # not translated because console usually not visible,
         # and may only accept ascii text
+        assert srcID is not None
         if srcID.startswith("data"):
             srcID = ""
         else:
@@ -159,10 +168,16 @@ class AnkiWebPage(QWebEnginePage):
     def _onCmd(self, str: str) -> Any:
         return self._onBridgeCmd(str)
 
-    def javaScriptAlert(self, frame: Any, text: str) -> None:
+    def javaScriptAlert(self, frame: Any, text: str | None) -> None:
+        if text is None:
+            return
+
         showInfo(text)
 
-    def javaScriptConfirm(self, frame: Any, text: str) -> bool:
+    def javaScriptConfirm(self, frame: Any, text: str | None) -> bool:
+        if text is None:
+            return False
+
         return askUser(text)
 
 
@@ -325,7 +340,9 @@ class AnkiWebView(QWebEngineView):
         # with target="_blank") and return view
         return AnkiWebView()
 
-    def eventFilter(self, obj: QObject, evt: QEvent) -> bool:
+    def eventFilter(self, obj: QObject | None, evt: QEvent | None) -> bool:
+        if evt is None:
+            return False
         if self._disable_zoom and is_gesture_or_zoom_event(evt):
             return True
 
@@ -374,14 +391,20 @@ class AnkiWebView(QWebEngineView):
     def onSelectAll(self) -> None:
         self.triggerPageAction(QWebEnginePage.WebAction.SelectAll)
 
-    def contextMenuEvent(self, evt: QContextMenuEvent) -> None:
+    def contextMenuEvent(self, evt: QContextMenuEvent | None) -> None:
         m = QMenu(self)
-        a = m.addAction(tr.actions_copy())
-        qconnect(a.triggered, self.onCopy)
+        self._maybe_add_copy_action(m)
         gui_hooks.webview_will_show_context_menu(self, m)
-        m.popup(QCursor.pos())
+        if m.actions():
+            m.popup(QCursor.pos())
 
-    def dropEvent(self, evt: QDropEvent) -> None:
+    def _maybe_add_copy_action(self, menu: QMenu) -> None:
+        if self.hasSelection():
+            a = menu.addAction(tr.actions_copy())
+            assert a is not None
+            qconnect(a.triggered, self.onCopy)
+
+    def dropEvent(self, evt: QDropEvent | None) -> None:
         if self.allow_drops:
             super().dropEvent(evt)
 
@@ -447,7 +470,9 @@ class AnkiWebView(QWebEngineView):
         return 1
 
     def setPlaybackRequiresGesture(self, value: bool) -> None:
-        self.settings().setAttribute(
+        settings = self.settings()
+        assert settings is not None
+        settings.setAttribute(
             QWebEngineSettings.WebAttribute.PlaybackRequiresUserGesture, value
         )
 
@@ -524,10 +549,10 @@ html {{ {font} }}
     def stdHtml(
         self,
         body: str,
-        css: Optional[list[str]] = None,
-        js: Optional[list[str]] = None,
+        css: list[str] | None = None,
+        js: list[str] | None = None,
         head: str = "",
-        context: Optional[Any] = None,
+        context: Any | None = None,
         default_css: bool = True,
     ) -> None:
         css = (["css/webview.css"] if default_css else []) + (
@@ -624,10 +649,13 @@ html {{ {font} }}
     def eval(self, js: str) -> None:
         self.evalWithCallback(js, None)
 
-    def evalWithCallback(self, js: str, cb: Callable) -> None:
+    def evalWithCallback(self, js: str, cb: Callable | None) -> None:
         self._queueAction("eval", js, cb)
 
-    def _evalWithCallback(self, js: str, cb: Callable[[Any], Any]) -> None:
+    def _evalWithCallback(self, js: str, cb: Callable[[Any], Any] | None) -> None:
+        page = self.page()
+        assert page is not None
+
         if cb:
 
             def handler(val: Any) -> None:
@@ -636,9 +664,9 @@ html {{ {font} }}
                     return
                 cb(val)
 
-            self.page().runJavaScript(js, handler)
+            page.runJavaScript(js, handler)
         else:
-            self.page().runJavaScript(js)
+            page.runJavaScript(js)
 
     def _queueAction(self, name: str, *args: Any) -> None:
         self._pendingActions.append((name, args))
@@ -677,7 +705,9 @@ html {{ {font} }}
             return
 
         if not self._filterSet:
-            self.focusProxy().installEventFilter(self)
+            focus_proxy = self.focusProxy()
+            assert focus_proxy is not None
+            focus_proxy.installEventFilter(self)
             self._filterSet = True
 
         if cmd == "domDone":
@@ -705,7 +735,7 @@ html {{ {font} }}
     def adjustHeightToFit(self) -> None:
         self.evalWithCallback("document.documentElement.offsetHeight", self._onHeight)
 
-    def _onHeight(self, qvar: Optional[int]) -> None:
+    def _onHeight(self, qvar: int | None) -> None:
         from aqt import mw
 
         if qvar is None:
@@ -842,5 +872,5 @@ html {{ {font} }}
         )
 
     @deprecated(info="use theme_manager.qcolor() instead")
-    def get_window_bg_color(self, night_mode: Optional[bool] = None) -> QColor:
+    def get_window_bg_color(self, night_mode: bool | None = None) -> QColor:
         return theme_manager.qcolor(colors.CANVAS)
